
agr and agrx should always be unified and synced.

Always 


# Always do
- Include in the plan to write tests for what is implemented
- Prefer simple over easy solutions
- When coming up with solutions to tasks and problems, Avoid having a laser focus on that one tasks or problem. Keep the broader codebase in mind and make sure to design solutions that will align with the codebase. 
- Have a jobs theory based mindset. Always keep the jobs to be done of the user that uses the software we build in mind.
- If any of the above principles is forgotten or violated by me, do not hesitate to challenge me on it.

# Ask first

# Never do

# Useful Documentation

Skills docs:
https://agentskills.io/specification
https://opencode.ai/docs/skills
https://code.claude.com/docs/en/skills
https://developers.openai.com/codex/skills
https://cursor.com/docs/context/skills
https://docs.github.com/en/copilot/concepts/agents/about-agent-skills

Slash commands / prompts docs:
https://code.claude.com/docs/en/slash-commands
https://opencode.ai/docs/commands/
https://cursor.com/docs/context/commands
https://developers.openai.com/codex/custom-prompts/

Subagents:
https://cursor.com/docs/context/subagents
https://code.claude.com/docs/en/sub-agents
https://opencode.ai/docs/agents/

Rules:
https://code.claude.com/docs/en/memory
https://cursor.com/docs/context/rules

CLAUDE.md and AGENTS.md documentation:
- Claude Code (CLAUDE.md): https://code.claude.com/docs/en/memory
- AGENTS.md (Open Standard): https://agents.md/
- Cursor (AGENTS.md Support): https://cursor.com/docs/agent/overview
- GitHub Copilot (AGENTS.md Support): https://github.blog/changelog/2025-08-28-copilot-coding-agent-now-supports-agents-md-custom-instructions/
- OpenAI Codex (AGENTS.md Guide): https://developers.openai.com/codex/guides/agents-md/
- OpenCode (AGENTS.md Rules): https://opencode.ai/docs/rules